==> pw-iso20022-SRU2022-9.3.7-sources.jar: com/prowidesoftware/swift/model/mx/dic/CommodityDerivative5.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Transparency calculation specific details for a freight commodity.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CommodityDerivative5", propOrder = {
    "sz",
    "avrgTmChrtr"
})
public class CommodityDerivative5 {

    @XmlElement(name = "Sz", required = true)
    protected String sz;
    @XmlElement(name = "AvrgTmChrtr", required = true)
    protected String avrgTmChrtr;

    /**
     * Gets the value of the sz property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSz() {
        return sz;
    }

    /**
     * Sets the value of the sz property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CommodityDerivative5 setSz(String value) {
        this.sz = value;
        return this;
    }

    /**
     * Gets the value of the avrgTmChrtr property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAvrgTmChrtr() {
        return avrgTmChrtr;
    }

    /**
     * Sets the value of the avrgTmChrtr property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CommodityDerivative5 setAvrgTmChrtr(String value) {
        this.avrgTmChrtr = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2023-10.1.6-sources.jar: com/prowidesoftware/swift/model/mx/dic/CommodityDerivative5.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Transparency calculation specific details for a freight commodity.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CommodityDerivative5", propOrder = {
    "sz",
    "avrgTmChrtr"
})
public class CommodityDerivative5 {

    @XmlElement(name = "Sz", required = true)
    protected String sz;
    @XmlElement(name = "AvrgTmChrtr", required = true)
    protected String avrgTmChrtr;

    /**
     * Gets the value of the sz property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSz() {
        return sz;
    }

    /**
     * Sets the value of the sz property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CommodityDerivative5 setSz(String value) {
        this.sz = value;
        return this;
    }

    /**
     * Gets the value of the avrgTmChrtr property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAvrgTmChrtr() {
        return avrgTmChrtr;
    }

    /**
     * Sets the value of the avrgTmChrtr property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public CommodityDerivative5 setAvrgTmChrtr(String value) {
        this.avrgTmChrtr = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
